@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2015 by Jakob Schröter <js@camaya.net>
+  Copyright (c) 2004-2016 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -26,7 +26,8 @@
 #include "util.h"
 
 #ifdef __MINGW32__
-# include <winsock.h>
+# include <winsock2.h>
+# include <ws2tcpip.h>
 #endif
 
 #if ( !defined( _WIN32 ) && !defined( _WIN32_WCE ) ) || defined( __SYMBIAN32__ )
@@ -43,7 +44,8 @@
 #endif
 
 #if defined( _WIN32 ) && !defined( __SYMBIAN32__ )
-# include <winsock.h>
+# include <winsock2.h>
+# include <ws2tcpip.h>
 #elif defined( _WIN32_WCE )
 # include <winsock2.h>
 #endif
@@ -227,7 +229,7 @@ namespace gloox
     struct sockaddr_storage they;
     int addr_size = sizeof( struct sockaddr_storage );
 #if defined( _WIN32 ) && !defined( __SYMBIAN32__ )
-    int newfd = static_cast<int>( accept( static_cast<SOCKET>( m_socket ), (struct sockaddr_storage*)&they, &addr_size ) );
+    int newfd = static_cast<int>( accept( static_cast<SOCKET>( m_socket ), (struct sockaddr*)&they, &addr_size ) );
 #else
     int newfd = accept( m_socket, (struct sockaddr*)&they, (socklen_t*)&addr_size );
 #endif
